import numpy as np
import scipy.stats as ss
import matplotlib.pyplot as plt
import seaborn as sb
import pystan

sm = pystan.StanModel(file = 'sdt_h.stan')

NFAa = 23; NCRa = 77;
NHa = 77;  NMa = 23;
NFAb = 50; NCRb = 50;
NHb = 77;  NMb = 23;
NFAc = 23; NCRc = 77;
NHc = 90;  NMc = 10;
NFAd = 40; NCRd = 60;
NHd = 89;  NMd = 11;
sdt_data = {'NFAa' : NFAa, 'NCRa': NCRa,
            'NHa': NHa, 'NMa': NMa,
            'NFAb': NFAb, 'NCRb': NCRb,
            'NHb': NHb, 'NMb': NMb,
            'NFAc': NFAc, 'NCRc':NCRc,
            'NHc': NHc, 'NMc': NMc,
            'NFAd': NFAd, 'NCRd': NCRd,
            'NHd': NHd, 'NMd':NMd}
fit = sm.sampling(data = sdt_data, n_jobs = 1)
print(fit)

da_med = np.median(fit['da'])
db_med = np.median(fit['db'])
dc_med = np.median(fit['dc'])
dd_med = np.median(fit['dd'])
sb.kdeplot(fit['da'], label = 'da')
sb.kdeplot(fit['db'], label = 'db')
sb.kdeplot(fit['dc'], label = 'dc')
sb.kdeplot(fit['dd'], label = 'dd')
plt.legend()
plt.title("Distributions of d'" +
          '\nda_med = {0:.2f}, db_med = {1:.2f}, dc_med = {2:.2f}, dd_med = {3:.2f}'.format(
          da_med, db_med, dc_med, dd_med))
plt.savefig('Figdprime.png')
plt.show()

Ca_med = np.median(fit['Ca'])
Cb_med = np.median(fit['Cb'])
Cc_med = np.median(fit['Cc'])
Cd_med = np.median(fit['Cd'])
sb.kdeplot(fit['Ca'], label = 'Ca')
sb.kdeplot(fit['Cb'], label = 'Cb')
sb.kdeplot(fit['Cc'], label = 'Cc')
sb.kdeplot(fit['Cd'], label = 'Cd')
plt.legend()
plt.title('Distributions of C' +
         '\nCa_med = {0:.2f}, Cb_med = {1:.2f}, Cc_med = {2:.2f}, Cd_med = {3:.2f}'.format(
         Ca_med, Cb_med, Cc_med, Cd_med))
plt.savefig('FigC.png')
plt.show()

dmu_h_med = np.median(fit['dmu_h'])
Cmu_h_med = np.median(fit['Cmu_h'])
sb.kdeplot(fit['dmu_h'], label = 'dmu_h')
sb.kdeplot(fit['Cmu_h'], label = 'Cmu_h')
plt.legend()
plt.title('dmu_h_med = {0:.2f}, Cmu_h_med = {1:.2f}'.format(dmu_h_med, Cmu_h_med))
plt.savefig('Figdmu_h.png')
plt.show()

dsgm_h_med = np.median(fit['dsgm_h'])
Csgm_h_med = np.median(fit['Csgm_h'])
sb.kdeplot(fit['dsgm_h'], label = 'dsgm_h')
sb.kdeplot(fit['Csgm_h'], label = 'Csgm_h')
plt.legend()
plt.title('dsgm_h_med = {0:.2f}, Csgm_h_med = {1:.2f}'.format(dsgm_h_med, Csgm_h_med))
plt.savefig('Figdsgm_h.png')
plt.show()

plt.hist(fit['dsgm_h'], label = 'dsgm_h', alpha = 0.3)
plt.hist(fit['Csgm_h'], label = 'Csgm_h', alpha = 0.3)
plt.legend()
plt.title('dsgm_h_med = {0:.2f}, Csgm_h_med = {1:.2f}'.format(dsgm_h_med, Csgm_h_med))
plt.savefig('Figdsgm_h_hist.png')
plt.show()
